pub struct OrganizationUserPolicyContext {
pub id: Uuid,
pub status: OrganizationUserStatusType,
pub role: OrganizationUserType,
pub enabled: bool,
pub use_policies: bool,
pub is_provider_user: bool,
}Expand description
A minimal set of data for a user in an organization. This provides the context needed to evaluate the policies that are applied to the user by the organization.
Fields
id: UuidThe organization’s unique ID.
status: OrganizationUserStatusTypeThe user’s membership status in the organization.
role: OrganizationUserTypeThe user’s role within the organization.
enabled: boolWhether the organization is enabled.
use_policies: boolWhether the organization’s plan supports policies.
is_provider_user: boolWhether the user is acting on behalf of a provider that manages the organization.